@@ -103,59 +103,42 @@ open(OUTPUT, ">$file2") or die "Couldn't open $file2 for writing\n";
 
 foreach $lines (@lines)              # loop thru file
 { 
-	$lines =~ s~<\!DOCTYPE HTML PUBLIC (.+?)>~<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?> \n<\!DOCTYPE html PUBLIC \"-\/\/W3C\/\/DTD XHTML 1.0 Strict\/\/EN\" \"http:\/\/www.w3.org\/TR\/xhtml1\/DTD\/xhtml1-strict.dtd\"> \n<html xmlns=\"http:\/\/www.w3.org\/1999\/xhtml\" xml:lang=\"en\">~ig;	
+	$lines =~ s~<\!DOCTYPE HTML PUBLIC (.+?)>~<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?> \n<\!DOCTYPE html PUBLIC \"-\/\/W3C\/\/DTD XHTML 1.0 Strict\/\/EN\" \"http:\/\/www.w3.org\/TR\/xhtml1\/DTD\/xhtml1-strict.dtd\"> \n<html xmlns=\"http:\/\/www.w3.org\/1999\/xhtml\" xml:lang=\"en\" lang=\"en\">~ig;	
 	$lines =~ s/<HTML>//ig;	 	
 	$lines =~ s!<META CONTENT=(.+?) HTTP-EQUIV=(.+?)>!!ig;
 	$lines =~ s!<META CONTENT =(.+?) HTTP-EQUIV =(.+?)>!!ig;
 	$lines =~ s!<META HTTP-EQUIV=(.+?) CONTENT=(.+?)>!!ig;
 	$lines =~ s!<META HTTP-EQUIV =(.+?) CONTENT =(.+?)>!!ig;
-	$lines =~ s/\bHTML\b/html/ig;	 
+	$lines =~ s/html/html/ig;	 
 	$lines =~ s/TITLE =|TITLE=/title=/ig;	 	
 	$lines =~ s/<TITLE/<title/ig;
 	$lines =~ s/<\/TITLE/<\/title/ig;
 	$lines =~ s/CONTENT =|CONTENT=/content=/ig;		
-	$lines =~ s/\bMETA\b/meta/ig;
+	$lines =~ s/META/meta/ig;
 	$lines =~ s/<META (.*?)>$/<meta $1\/>/ig;
-	$lines =~ s/<LINK (.+?)>/<link $1\/>/ig;
-	$lines =~ s/\bNAME\b/name/ig;	
+	$lines =~ s/<LINK (.+?)>/<link $1\/>/ig;	
 	$lines =~ s/<HEAD/<head/ig;
 	$lines =~ s/<\/HEAD/<\/head/ig;
 	$lines =~ s/<LINK/<link/ig;	
-	$lines =~ s/\bHREF\b/href/ig;
+	$lines =~ s/HREF/href/ig;
 	$lines =~ s/TYPE =|TYPE=/type=/ig;	
+	$lines =~ s/type=\"(\w+)\"/type=\"\L$1\"/ig;	
 	$lines =~ s/REL =|REL=/rel=/ig;
 	$lines =~ s/MEDIA =|MEDIA=/media=/ig;		
-	$lines =~ s/\bBODY\b/body/ig;	
+	$lines =~ s/BODY/body/ig;	
 	$lines =~ s/<P>/<p>/ig;	 	
 	$lines =~ s/<\/P>/<\/p>/ig;	
 	$lines =~ s!<IMG (.+?)>!<img $1\/>!mig;
-	$lines =~ s!<\bIMG\b!<img!ig;
-	$lines =~ s!<\bcolor\b!<color!ig;
 	$lines =~ s/SRC/src/ig;
-	$lines =~ s/src=\"(\w+)\"/src=\"$1\"/ig;
 	$lines =~ s/CLASS =|CLASS=/class=/ig;
-	$lines =~ s/class=(\w+)/class=\"$1\"/ig;	
 	$lines =~ s/ALT =|ALT=/alt=/ig;
-	$lines =~ s/onMouseOut/onmouseout/ig;
-	$lines =~ s/onMouseOver/onmouseover/ig;
-	$lines =~ s/onMouseDown/onmousedown/ig;
-	$lines =~ s/onMouseMove/onmousemove/ig;
-	$lines =~ s/onMouseUp/onmouseup/ig;	
-	$lines =~ s/onClick/onclick/ig;
-	$lines =~ s/onDblClick/ondblclick/ig;
-	$lines =~ s/onKeyDown/onkeydown/ig;
-	$lines =~ s/onKeyPress/onkeypress/ig;
-	$lines =~ s/onKeyUp/onkeyup/ig;	
-	$lines =~ s/alt=(\w+)/alt=\"$1\"/ig;	
-	$lines =~ s/\bHEIGHT\b/height/ig;
-	$lines =~ s/height=(\w+)/height=\"$1\"/ig;	
-	$lines =~ s/\bWIDTH\b/width/ig;
-	$lines =~ s/width=(\w+)/width=\"$1\"/ig;	
-	$lines =~ s/\bDIV\b/div/ig;
+	$lines =~ s/HEIGHT/height/ig;
+	$lines =~ s/WIDTH/width/ig;
+	$lines =~ s/DIV/div/ig;
 	$lines =~ s/<SPAN/<span/ig;
 	$lines =~ s/<\/SPAN/<\/span/ig;
+	$lines =~ s/NAME=/id=/ig;	
 	$lines =~ s/ID =|ID=/id=/ig;
-	$lines =~ s/id=\"(\w+)\"/id=\"$1\"/ig;	
 	$lines =~ s/<LI/<li/ig;
 	$lines =~ s/<\/LI/<\/li/ig;
 	$lines =~ s/<A/<a/ig;
@@ -170,16 +153,16 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<FORM/<form/ig;	
 	$lines =~ s/<UL/<ul/ig;	 	
 	$lines =~ s/<\/UL>/<\/ul>/ig;		
-	$lines =~ s/<B>/<span style="font-weight: bold">/ig;	 	
+	$lines =~ s/<B>/<b>/ig;	 	
 	$lines =~ s/<\/B>/<\/b>/ig;		
-	$lines =~ s/\bMENU\b/menu/ig;
-	$lines =~ s/\bSMALL\b/small/ig;
+	$lines =~ s/MENU /menu /ig;
+	$lines =~ s/SMALL/small/ig;
 	$lines =~ s/<\/UL/<\/ul/ig;
 	$lines =~ s/<\/ACRONYM/<\/acronym/ig;
 	$lines =~ s/<ACRONYM/<acronym/ig;
 	$lines =~ s/<\/ABBR/<\/abbr/ig;
 	$lines =~ s/<ABBR/<abbr/ig;	
-	$lines =~ s/\bBLOCKQUOTE\b/blockquote/ig;
+	$lines =~ s/BLOCKQUOTE/blockquote/ig;
 	$lines =~ s/<ADDRESS/<address/ig;
 	$lines =~ s/<\/ADDRESS/<\/address/ig;	
 	$lines =~ s/<CITE/<cite/ig;
@@ -188,9 +171,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/CODE/<\/code/ig;	
 	$lines =~ s/<DFN/<dfn/ig;
 	$lines =~ s/<\/DFN/<\/dfn/ig;	
-	$lines =~ s/<KBD/<kbd/ig;
-	$lines =~ s/<\/KBD/<\/kbd/ig;		
-	$lines =~ s/<PRE/<pre/ig;	
+	$lines =~ s/<PRE/<pre/ig;
 	$lines =~ s/<\/PRE/<\/pre/ig;	
 	$lines =~ s/<Q/<q/ig;
 	$lines =~ s/<\/Q/<\/q/ig;	
@@ -214,7 +195,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/PARAM/<\/param/ig;	
 	$lines =~ s/<OBJECT/<object/ig;
 	$lines =~ s/<\/OBJECT/<\/object/ig;	
-	$lines =~ s/\bBIG\b/big/ig;
+	$lines =~ s/BIG/big/ig;
 	$lines =~ s/<SUP/<sup/ig;
 	$lines =~ s/<\/SUP/<\/sup/ig;	
 	$lines =~ s/<SUB/<sub/ig;
@@ -229,15 +210,14 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/BDO/<\/bdo/ig;	
 	$lines =~ s/<LEGEND/<legend/ig;
 	$lines =~ s/<\/LEGEND/<\/legend/ig;	
-	$lines =~ s/\bOPTION\b/option/ig;
+	$lines =~ s/OPTION/option/ig;
 	$lines =~ s/<AREA/<area/ig;
 	$lines =~ s/<\/AREA/<\/area/ig;	
 	$lines =~ s/<MAP/<map/ig;
 	$lines =~ s/<\/MAP/<\/map/ig;	
-	$lines =~ s/\bISMAP\b/ismap/ig;
-	$lines =~ s/\bNOSCRIPT\b/noscript/ig;
-	$lines =~ s/\bSCRIPT\b/script/ig;
-	$lines =~ s!<SCRIPT type="text/javascript"|SCRIPT language=\"JavaScript\">!<script type=\"text\/javascript\">!ig;	
+	$lines =~ s/ISMAP/ismap/ig;
+	$lines =~ s/NOSCRIPT/noscript/ig;
+	$lines =~ s/SCRIPT/script/ig;
 	$lines =~ s/<BASE/<base/ig;
 	$lines =~ s/<\/BASE/<\/base/ig;	
 	$lines =~ s/<RUBY/<ruby/ig;
@@ -262,26 +242,24 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/BLINK/<\/blink/ig;		
 	$lines =~ s/<EMBED/<embed/ig;
 	$lines =~ s/<\/EMBED/<\/embed/ig;	
-	$lines =~ s/\bPLUGINSPAGE\b/pluginspage/ig;
-	$lines =~ s/\bPLUGINURL\b/pluginurl/ig;
-	$lines =~ s/\bHIDDEN\b/hidden/ig;
-	$lines =~ s/\bAUTOSTART\b/autostart/ig;
-	$lines =~ s/\bLOOP\b/loop/ig;
-	$lines =~ s/\bPLAYCOUNT\b/playcount/ig;
+	$lines =~ s/PLUGINSPAGE/pluginspage/ig;
+	$lines =~ s/PLUGINURL/pluginurl/ig;
+	$lines =~ s/HIDDEN/hidden/ig;
+	$lines =~ s/AUTOSTART/autostart/ig;
+	$lines =~ s/LOOP/loop/ig;
+	$lines =~ s/PLAYCOUNT/playcount/ig;
 	$lines =~ s/VOLUME =|VOLUME=/volume=/ig;
-	$lines =~ s/CONTROLS =|CONTROLS=/controls=/ig;
-	$lines =~ s/CONTROLLER= |CONTROLLER=/controller=/ig;
-	$lines =~ s/\bMASTERSOUND\b/mastersound/ig;
-	$lines =~ s/\bSTARTTIME\b/starttime/ig;
-	$lines =~ s/\bENDTIME\b/endtime/ig;	
-	$lines =~ s/ALIGN =|ALIGN=/align=/ig; 	
-	$lines =~ s/align=\"(\w+)\"/align=\"\L$1\"/ig; 		
+	$lines =~ s/CONTROLS =|VOLUME=/controls=/ig;
+	$lines =~ s/CONTROLLER= |VOLUME=/controller=/ig;
+	$lines =~ s/MASTERSOUND/mastersound/ig;
+	$lines =~ s/STARTTIME/starttime/ig;
+	$lines =~ s/ENDTIME/endtime/ig;	
+	$lines =~ s/ALIGN =\"(\w+)\"|ALIGN=\"(\w+)\"/style=\"text-align: $1\"/ig; 		
 	$lines =~ s/SUMMARY =|VOLUME=/summary=/ig; 
 	$lines =~ s/DIR =|DIR=/dir=/ig; 		
 	$lines =~ s/dir=\"(\w+)\"/dir=\"\L$1\"/ig; 		
-	$lines =~ s/LANG =|LANG=/xml:lang=/ig; 		
-	$lines =~ s/xml:lang=\"(\w+)\"/xml:lang=\"\L$1\"/ig; 			
-	$lines =~ s/xml:lang=\"(\w+)\" lang=\"(\w+)\"/xml:lang=\"\L$1\"/ig;
+	$lines =~ s/LANG =|LANG=/lang=/ig; 		
+	$lines =~ s/lang=\"(\w+)\"/lang=\"\L$1\"/ig; 			
 	$lines =~ s/SPAN =|SPAN=/span=/ig; 
 	$lines =~ s/<TABLE/<table/ig;
 	$lines =~ s/<\/TABLE/<\/table/ig;	
@@ -291,29 +269,21 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/TH>/<\/th>/ig;
 	$lines =~ s/<TR/<tr/ig;			
 	$lines =~ s/<\/TR/<\/tr/ig;	
-	$lines =~ s/\bTBODY\b/tbody/ig;	
+	$lines =~ s/TBODY/tbody/ig;	
 	$lines =~ s/<CAPTION/<caption/ig;
 	$lines =~ s/<\/CAPTION/<\/caption/ig;		
-	$lines =~ s/\bTHEAD\b/thead/ig;	
-	$lines =~ s/\bTFOOT\b/tfoot/ig;	
-	$lines =~ s/\bCOLGROUP\b/colgroup/ig;	
+	$lines =~ s/THEAD/thead/ig;	
+	$lines =~ s/TFOOT/tfoot/ig;	
+	$lines =~ s/COLGROUP/colgroup/ig;	
 	$lines =~ s/<COL/<col/ig;
 	$lines =~ s/<\/COL/<\/col/ig;			
 	$lines =~ s/ROWSPAN =|ROWSPAN=/rowspan=/ig; 
 	$lines =~ s/COLSPAN =|COLSPAN=/colspan=/ig; 
-	$lines =~ s/\bNOWRAP\b/nowrap/ig; 
+	$lines =~ s/NOWRAP/nowrap/ig; 
 	$lines =~ s/AXIS =|AXIS=/axis=/ig; 
 	$lines =~ s/STYLE =|STYLE=/style=/ig; 
-	$lines =~ s/\bBACKGROUND/background/ig; 
-	$lines =~ s/\bPADDING/padding/ig; 
-	$lines =~ s/\bTOP/top/ig; 
-	$lines =~ s/\bLEFT/left/ig; 
-	$lines =~ s/\bRIGHT/right/ig; 
-	$lines =~ s/\bBOTTOM/bottom/ig; 
-	$lines =~ s/\bIMAGE/image/ig; 
-	$lines =~ s/REPEAT\b/repeat/ig; 	
-	$lines =~ s/BGcolor =|BGcolor=/bgcolor=/ig; 
-	$lines =~ s/color =|color=/color=/ig;
+	$lines =~ s/BGCOLOR =|BGCOLOR=/bgcolor=/ig; 
+	$lines =~ s/COLOR =|COLOR=/color=/ig;
 	$lines =~ s/VALIGN =|VALIGN=/valign=/ig;
 	$lines =~ s/CHAR =|CHAR=/char=/ig;
 	$lines =~ s/CHAROFF =|CHAROFF-/charoff=/ig;
@@ -337,7 +307,6 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/VLINK =|VLINK=/vlink=/ig;
 	$lines =~ s/ALINK =|ALINK=/alink=/ig;	
 	$lines =~ s/<INPUT (.+?)>/<input $1\/>/ig;			
-	$lines =~ s/<HR (.+?)>/<hr $1\/>/ig;			
 	$lines =~ s/<BUTTON/<button/ig;
 	$lines =~ s/<\/button/<\/button/ig;					
 	$lines =~ s/<SELECT/<select/ig;
@@ -356,20 +325,22 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/<\/LABEL/<\/label/ig;	
 	$lines =~ s/ACCESSKEY =|ACCESSKEY=/accesskey=/ig;
 	$lines =~ s/METHOD =|METHOD=/method=/ig;
-	$lines =~ s/method=\"(\w+)\"/method=\"\L$1\"/ig; 			
 	$lines =~ s/ACTION =|ACTION=/action=/ig;
 	$lines =~ s/ENCTYPE =|ENCTYPE=/enctype=/ig;
 	$lines =~ s/<LEGEND/<legend/ig;
 	$lines =~ s/<\/LEGEND/<\/legend/ig;	
+	$lines =~ s/selected value=\"(\w*)\"/selected="selected" value=\"$1\"/ig; #not sure about this!!
 	$lines =~ s/VALUE =|VALUE=/value=/ig;
+	$lines =~ s/value=(\w*)/value=\"\L$1\"/ig;		
+	$lines =~ s/cols=(\d*)/cols=\"$1\"/ig;		
+	$lines =~ s/rows=(\d*)/rows=\"$1\"/ig;		
 	$lines =~ s/<FIELDSET/<fieldset/ig;
 	$lines =~ s/<\/FIELDSET/<\/fieldset/ig;	
-	$lines =~ s/FOR =|FOR=/for=/ig;		
+	$lines =~ s/FOR =|FOR=/for=/ig;	
 	$lines =~ s/MAXLENGTH =|MAXLENGTH=/maxlength=/ig;	
 	$lines =~ s/SIZE =|SIZE=/size=/ig;	
-	$lines =~ s/\bMARGIN\b/margin/ig;	
-	$lines =~ s!\/\/>!/>!g;
-	
+	$lines =~ s/size=\"(\d*)\"/size=\"\L$1\"/ig;	
+			
 	print OUTPUT $lines;
 }
 
@@ -397,15 +368,15 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/NAME/name/ig;
 	$lines =~ s/LINK/link/ig;		
 	$lines =~ s/BODY/body/ig;		
-	$lines =~ s/\bP\b/p/ig;	 				 		
+	$lines =~ s/P/p/ig;	 				 		
 	$lines =~ s/HEIGHT/height/ig;
 	$lines =~ s/WIDTH/width/ig;
 	$lines =~ s/DIV/div/ig;
 	$lines =~ s/SPAN/span/ig;
 	$lines =~ s/IMG/img/ig;
-	$lines =~ s/\bID\b/id/ig;
-	$lines =~ s/\bLI\b/li/ig;
-	$lines =~ s/\bA\b/a/ig;
+	$lines =~ s/ID/id/ig;
+	$lines =~ s/LI/li/ig;
+	$lines =~ s/A/a/ig;
 	$lines =~ s/BR/br/ig;	
 	$lines =~ s/FORM/form/ig;
 	$lines =~ s/UL/ul/ig;
@@ -426,33 +397,37 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/THEAD/thead/ig;	
 	$lines =~ s/TFOOT/tfoot/ig;	
 	$lines =~ s/COLGROUP/colgroup/ig;	
-	$lines =~ s/COL/col/ig;				
+	$lines =~ s/COL/col/ig;			
+	$lines =~ s/EM/em/ig;	
+	$lines =~ s/B/b/ig;	
+	$lines =~ s/I/i/ig;	
+	$lines =~ s/U/u/ig;	
 	$lines =~ s!H(\d{1})!h$1!ig;
 	$lines =~ s/BLINK/blink/ig;	
 	$lines =~ s/EMBED/embed/ig;			
-	$lines =~ s/\bEM\b/em/ig;	
-	$lines =~ s/\bB\b/b/ig;	
-	$lines =~ s/\bI\b/i/ig;	
-	$lines =~ s/\bU\b/u/ig;	
+	$lines =~ s/EM/em/ig;	
+	$lines =~ s/B/b/ig;	
+	$lines =~ s/I/i/ig;	
+	$lines =~ s/U/u/ig;	
 	$lines =~ s/BLINK/blink/ig;	
 	$lines =~ s/EMBED/embed/ig;				
 	$lines =~ s/NOWRAP/nowrap/ig; 
 	$lines =~ s/AXIS/axis/ig;	
-	$lines =~ s/BGcolor/bgcolor/ig;
-	$lines =~ s/color/color/ig;
-	$lines =~ s/VALIGN/valign/ig;
-	$lines =~ s/CHAR/char/ig;
-	$lines =~ s/CHAROFF/charoff/ig;
-	$lines =~ s/FRAME/frame/ig;
-	$lines =~ s/RULES/rules/ig;
-	$lines =~ s/BORDER/border/ig;
-	$lines =~ s/CELLSPACING/cellspacing/ig;
-	$lines =~ s/CELLPADDING/cellpadding/ig;
-	$lines =~ s/HEADERS/headers/ig;
-	$lines =~ s/TEXT/text/ig;
-	$lines =~ s/BACKGROUND/background/ig;
-	$lines =~ s/VLINK/vlink/ig;
-	$lines =~ s/ALINK/alink/ig;		
+	$lines =~ s/BGCOLOR/bgcolor/ig;
+	$lines =~ s!COLOR!color!ig;
+	$lines =~ s!VALIGN!valign!ig;
+	$lines =~ s!CHAR!char!ig;
+	$lines =~ s!CHAROFF!charoff!ig;
+	$lines =~ s!FRAME!frame!ig;
+	$lines =~ s!RULES!rules!ig;
+	$lines =~ s!BORDER!border!ig;
+	$lines =~ s!CELLSPACING!cellspacing!ig;
+	$lines =~ s!CELLPADDING!cellpadding!ig;
+	$lines =~ s!HEADERS!headers!ig;
+	$lines =~ s!TEXT!text!ig;
+	$lines =~ s!BACKGROUND!background!ig;
+	$lines =~ s!VLINK!vlink!ig;
+	$lines =~ s!ALINK!alink!ig;		
 	$lines =~ s/INPUT/input/ig;	
 	$lines =~ s/BUTTON/button/ig;	
 	$lines =~ s/SELECT/select/ig;	
@@ -467,7 +442,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/CODE/code/ig;
 	$lines =~ s/DFN/dfn/ig;	
 	$lines =~ s/PRE/pre/ig;	
-	$lines =~ s/\bQ\b/q/ig;	
+	$lines =~ s/Q/q/ig;	
 	$lines =~ s/SAMP/samp/ig;	
 	$lines =~ s/PRE/pre/ig;	
 	$lines =~ s/STRONG/strong/ig;	
@@ -499,36 +474,7 @@ foreach $lines (@lines)              # loop thru file
 	$lines =~ s/RB/rb/ig;	
 	$lines =~ s/RT/rt/ig;	
 	$lines =~ s/RP/rp/ig;	
-	$lines =~ s/MARGIN/margin/ig;
-	$lines =~ s/TOP/top/ig;
-	$lines =~ s/BOTTOM/bottom/ig;
-	$lines =~ s/RIGHT/right/ig;
-	$lines =~ s/LEFT/left/ig;
-	$lines =~ s/FONT/font/ig;
-	$lines =~ s/HOVER/hover/ig;
-	$lines =~ s/WEIGHT/weight/ig;
-	$lines =~ s/SIZE/size/ig;
-	$lines =~ s/CURSOR/cursor/ig;
-	$lines =~ s/URL/url/ig;
-	$lines =~ s/STYLE/style/ig;
-	$lines =~ s/FAMILY/family/ig;
-	$lines =~ s/COLLAPSE/collapse/ig;			
-	$lines =~ s/ALIGN/align/ig;		
-	$lines =~ s/DECORATION/decoration/ig;		
-	$lines =~ s/LIST/list/ig;		
-	$lines =~ s/IMAGE/image/ig;		
-	$lines =~ s/REPEAT/repeat/ig;		
-	$lines =~ s/PADDING/padding/ig;		
-	$lines =~ s/LINE/line/ig;		
-	$lines =~ s/DISPLAY/display/ig;		
-	$lines =~ s/FILTER/filter/ig;		
-	$lines =~ s/TYPE/type/ig;		
-	$lines =~ s/FLOAT/float/ig;
-	$lines =~ s/POSITION/position/ig;
-	$lines =~ s/INDENT/indent/ig;
-	$lines =~ s/\bHR\b/indent/ig;
-	$lines =~ s/VARIANT/variant/ig;
-				
+			
 	print OUTPUT $lines;
 }
 
